//----------------------------------
// All necessary function for AD9833
// - initialization of AD9833 module
// - write to AD9833 register
//----------------------------------


//---------------------------------------------------------------------------
// Init AD9833 module
// - init SPI
// - init AD9833 register
//-----------------------------------------------------------------------------
void ad9833_init(void) {
  // SG_Reset();
  // SG_freqReset(calcFreq(freqSGLo), waveType);
	cli();
	DDRB |= 0x2E;		// Out for SCK,MOSI, pin 10, ping 9					
	SPCR = 0x58;		// SPI init : SPE, MASTER, CPOL (SPI_MODE2)
	SPSR = 0x01;		// SPIX2 active
	PORTB |= (1<<1);	// CS pin 9
	sei();				// Autorisation interruption
}

//----------------------
// Write AD9833 register
//----------------------
void write_AD9833(int AD_Register) {
    PORTB &= ~(1<<1);					// Chip select pin 9
    SPDR = highByte(AD_Register);		// Copie MSB + 4 bits programmation du DAC (buffered, 1x gain et active mode)
    while (!(SPSR & (1<<SPIF)));		// Attente de la copie
    SPDR = lowByte(AD_Register);		// Copie du LSB
    while (!(SPSR & (1<<SPIF)));		// Attente de la copie
    PORTB |= (1<<1);					// Chip un-select pin 9
}

//-----------------------------------------------------------------------------
// Reset AD9833
// set frequency
// set wave type
//-----------------------------------------------------------------------------
void SG_frequencySet(long frequency, int wave) {
  long fl = frequency * (0x10000000 / 25000000.0);				// calc frequency for AD9833

  // reset (b:9)
  // LSB+MSB write consecutively (b:13)
  write_AD9833(0x2100);

  // write lower part of frequency. only the 14 first bits, mask with 3FFF (b0:13)
  // or with 0x4000 to force bit 14 to 1 (FREQ0 write)
  write_AD9833((int)(fl & 0x3FFF) | 0x4000);
  // write upper part of frequency.
  // shift 14 bits right (b0:13)
  // or with 0x4000 to force bit 14 to 1 (FREQ0 write)
  write_AD9833((int)((fl & 0xFFFC000) >> 14) | 0x4000);
  // Setup for phase write  
  write_AD9833(0xC000);
  // Send control register for wave form select
  // if 0x0000, means sinus, freq0, phase0, onboard DAC, internal clock
  write_AD9833(wave);
}

//----------------------------------------
// Change current frequency of transmitter
// after some delay
//----------------------------------------
void changeFrequencyTransmitterOnDelay(void) {
	if (timeFreqTransmitterChange) {
		if (timeFreqTransmitterChange+DELAY_TRANSMITTER_CHANGE < millis()) {		// If time elapsed
			timeFreqTransmitterChange=0;										// no change to do anymore (until real change with encoders)
			SG_frequencySet(currentChannelTransmitter*1000L,AD_SINE_WAVE);
		}
	}
}

