//---------------------------------------------------
// management of presets for the transmitter program.
// 16 preselections saved in the arduino eeprom
//---------------------------------------------------


//---------------------------------------------
// Load preset
// tune frequency of the receiver (SI4703)
// tune frequency of the transmitter (AD9833)
// (optionnal) make ajustement for antenna coil
//---------------------------------------------
void LoadPreset(byte numpreset) {
int i;
    myaddress = (numpreset-1)*PRESETSIZE;				// Compute address
	// FM tuning
	myByte1=EEPROM.read(myaddress++);					// MSB current FM channel
    myByte2=EEPROM.read(myaddress++);					// LSB current FM channel
	currentChannel=word(myByte1,myByte2);				// build integer
	gotoChannel(currentChannel);						// Set default channel and tune
	
	// transmitter tuning
	myByte1=EEPROM.read(myaddress++);					// MSB current channel transmitter
    myByte2=EEPROM.read(myaddress++);					// LSB current channel transmitter
	currentChannelTransmitter=word(myByte1,myByte2);	// build integer	
	SG_frequencySet(currentChannelTransmitter*1000L,AD_SINE_WAVE);	// Set frequency of the transmitter
	
	// type of coil use in antenna circuit (no used yet...)
	currentAntennaCoil=EEPROM.read(myaddress++);		// commutation output coil
	setCoil();
	// transmitter antenna coil tuning
	myByte1=EEPROM.read(myaddress++);					// MSB tuning antenna coil
    myByte2=EEPROM.read(myaddress++);					// LSD tuning antenna coil
	TuningAntennaCoil=word(myByte1,myByte2);			// build integer
	//setTuningAntennaCoil();							// Set tuning of the antenna coil (NOT USED...)
	
	// tuner volume
	currentVolumeSI4703=EEPROM.read(myaddress++);		// read SI4703 volume level
	setVolume(currentVolumeSI4703);									// Set default volume level

	// Station name
    for (i=0;i<8;i++) { 								// read current station name
		StationName[i]=EEPROM.read(myaddress++);
    }
	if (strlen(StationName)) {							// if station name already decoded
		StationNameStatus=SN_READY;						// then we use it
		lcd.setCursor(11,0);
		lcd.print(StationName);
	}
}

//-------------------------------------------
// Save current setting at numpreset position
//-------------------------------------------
void SavePreset(byte numpreset) {
int i;
    myaddress = (numpreset-1)*PRESETSIZE;								// Compute address
	
	EEPROM.write(myaddress++, highByte(currentChannel));				// WR tuning SI4703
	EEPROM.write(myaddress++, lowByte(currentChannel));
	
	EEPROM.write(myaddress++, highByte(currentChannelTransmitter));		// WR tuning AD9833
	EEPROM.write(myaddress++, lowByte(currentChannelTransmitter));
	
	EEPROM.write(myaddress++, currentAntennaCoil);						// WR antenna coil commutation
	
	EEPROM.write(myaddress++, highByte(TuningAntennaCoil));				// WR tuning antenna coil
	EEPROM.write(myaddress++, lowByte(TuningAntennaCoil));
	
	EEPROM.write(myaddress++, currentVolumeSI4703);						// WR current volume
	// Station name
    for (i=0;i<8;i++) { 
		EEPROM.write(myaddress++,StationName[i]);
    }
	
}

//----------------------------------------------------------------
// Init the eeprom
// clear station name
// tune 88.0mhz
// 150Khz for transmitter
// 100pf for antenna coil
// coil select 0
// 5 for volume level
// We do this 'MAXPRESETS' times
//----------------------------------------------------------------
void FormatEEPROM(void) {
byte i;
	currentChannel=880;
	memset(StationName,0,sizeof(StationName));
	currentChannelTransmitter=200;
	currentAntennaCoil=0;
	TuningAntennaCoil=100;
	currentVolumeSI4703=10;
	lcd.clear();
	lcd.setCursor(0,0);
	lcd.print(F("Format EEPROM"));
	lcd.setCursor(0,1);
	for (i=0; i<MAXPRESETS;i++) {
		lcd.print(F("."));
		SavePreset(i+1);
		delay(100);
	}
}

