//--------------------------------------------------------
// display numerical value
// with non significant 0 at start
// nbdigits = length (between 1 and 3)
//--------------------------------------------------------
void digitsLcdPos(int valeur, byte x, byte y, byte nbdigits) {
  lcd.setCursor(x,y);
  if (nbdigits==3 && valeur <100)
      lcd.print(F("0"));
  if (valeur<10)
      lcd.print(F("0"));
  lcd.print(valeur,DEC);
}
//---------------------
// refresh station name
// clear old one
// refresh new one
//---------------------
void refresh_StationName(void) {
	lcd.setCursor(11,0);
	lcd.print(F("        "));
	lcd.setCursor(11,0);
	lcd.print(StationName);
}

//---------------------------------
// Display one byte in Binary
//---------------------------------
void aff_lcd_binary(byte oct) {
byte i;
	lcd.print(oct);
	lcd.print(":");
    for (i=8; i>0; i--) {
        if (bitRead(oct,i-1))
            lcd.print(F("1"));
        else
            lcd.print(F("0"));
    }
}

//-------------------------
// Display SI4703 frequency 
// with "." separator
//-------------------------
void affFreqReceiver(byte x, byte y,int displayFreq) {
char *p,*d;
char c;
char strFreq[8];
	memset(strFreq,0,sizeof(strFreq));	// Clear buffer
	itoa(displayFreq,strFreq,10);		// Convert int frequency to char
	p=strFreq+strlen(strFreq)-1;		// Pointer p on last digit in string
	d=p+1;								// Pointer d on the end of string (/0)
	*d=*p;								// Add a new car equal to current last one
	*p='.';								// Replace the old ending char with '.'
	lcd.setCursor(x,y);
	if (strlen(strFreq) < 5)
		lcd.print(F(" "));
	lcd.print(strFreq);
}

//------------------------------------
// Display frequency of transmitter
// with 4 chars, justified on the right
//------------------------------------
void affFreqTransmitter(byte x, byte y,int displayFreq) {
	lcd.setCursor(x,y);
	if (displayFreq >=150 && displayFreq<1000)
		lcd.print(F(" "));
	if (displayFreq<150 || displayFreq > 1650)
		lcd.print("----");
	else
		lcd.print(displayFreq);
}

//------------------------------------
// Display current volume of the tuner
// on 2 char, justified on the right
//------------------------------------
void affVolume(byte x, byte y, byte currentvolume) {
	lcd.setCursor(x,y);
	if (currentvolume >=0 && currentvolume<10)
		lcd.print(F(" "));
	if (currentvolume<0 || currentvolume > 15)
		lcd.print("--");
	else
		lcd.print(currentvolume);
}

//-------------------------------------------
// Display current coil selection
// LW+MW : mean LW coil and MW in serial mode
// LW : only LW
// MW : only MW
//-------------------------------------------
void affCoilSelection(byte x, byte y, byte currentCoilSelection)  {
	lcd.setCursor(x,y);
	switch(currentCoilSelection) {
		case 0 : 
			lcd.print("LW+MW");
			break;
		case 1 : 
			lcd.print("   LW");
			break;
		case 2 : 
			lcd.print("   MW");
			break;
	}
}
//------------------------------------
// Display current preset number
//------------------------------------
void affPreset(byte x, byte y, byte preset) {
	lcd.setCursor(x,y);
	if (preset >=1 && preset<10)
		lcd.print(F("0"));
	if (preset<0 || preset > 16)
		lcd.print("--");
	else
		lcd.print(preset);
}


//----------------------------
// Init LCD
// start the LCD and backlight
// create some char
//----------------------------
void init_lcd(void) {
	lcd.init();										// Lcd init
	lcd.backlight();								// Lcd backlightRetroeclairage
	lcd.home();
	lcd.setCursor(0,0);
	lcd.print(F("********************"));   		// Affichage titre 
	lcd.setCursor(0,1);
	lcd.print(F("*** EMETTEUR 1.0 ***"));   		// Affichage titre 
	lcd.setCursor(0,2);
	lcd.print(F("********************"));   		// Affichage titre 
	lcd.setCursor(0,3);
	delay(1000);
	// Init lcd user char table
	lcd.createChar(CHAR_UP, symbup);
	lcd.createChar(CHAR_DOWN, symbdown);
	lcd.createChar(CHAR_TRIRIGHT,symbTriRight);
	lcd.createChar(CHAR_TRILEFT,symbTriLeft);
	lcd.createChar(CHAR_STOP,symbStop);
	lcd.createChar(CHAR_BARRE,symbBarre);
	lcd.createChar(CHAR_ANTENNA,symbAntenna);
	lcd.clear();
}

// ---------------
// Init background
// ---------------
void init_background(void) {
	lcd.clear();
	lcd.setCursor(7,0);
	lcd.print(F("Mhz <No RDS>"));
	lcd.setCursor(7,1);
	lcd.print(F("Khz "));
	lcd.write(CHAR_ANTENNA);
	lcd.print(F("-XMIT-"));
	lcd.write(CHAR_ANTENNA);
	lcd.setCursor(7,2);
	lcd.print(F("Coi"));
	lcd.setCursor(7,3);
	lcd.print(F("Vol"));
	lcd.setCursor(16,3);
	lcd.print(F("[  ]"));
}

// ---------------
// Refresh background
// ---------------
void refresh_display(void) {
	affFreqReceiver(1,0,currentChannel);
	affFreqTransmitter(2,1,currentChannelTransmitter);
	affCoilSelection(1,2,currentAntennaCoil);
	affVolume(4,3,currentVolumeSI4703);
	affPreset(17,3,currentPreset);
	lcd.setCursor(11,0);
	lcd.print(F("<No RDS>"));
}


