//-------------------------
// main menu
// at the top of the tree
// you change presets here
//-------------------------
void menu_main(void) {
	readRdsStationNB(StationName, 40);
	if (StationNameStatus==SN_READY) {
		StationNameStatus=SN_READ;
		refresh_StationName();
	}
	valbouton=readButtons();					// read button value
	if (valbouton==B_ENC1) {					// if encoder pressed
		if (currentMenu==2) {					// Test if we are setting transmitter frequency
			delay(300);
			valbouton=readButtons();		
			if (valbouton==B_MAINT) {
				if (!FreqTransmitInc) {
					FreqTransmitInc=1;
					lcd.setCursor(1,1);
					lcd.print("*");
				}
				else {
					FreqTransmitInc=0;
					lcd.setCursor(1,1);
					lcd.print(" ");
				}
				return;
			}
		}
		currentMenu++;							// change current menu
		delay(100);								// to prevent move of the encoder
		switch(currentMenu) {
			case 1:
				// display new pointer
				lcd.setCursor(0,currentMenu-1);
				lcd.write(CHAR_TRIRIGHT);
				lcd.setCursor(10,currentMenu-1);
				lcd.write(CHAR_TRILEFT);
				break;
			case 2:
			case 3:
			case 4:
				// clear old pointer on the screen
				lcd.setCursor(0,currentMenu-2);
				lcd.print(F(" "));
				lcd.setCursor(10,currentMenu-2);
				lcd.print(F(" "));
				// display new pointer
				lcd.setCursor(0,currentMenu-1);
				lcd.write(CHAR_TRIRIGHT);
				lcd.setCursor(10,currentMenu-1);
				lcd.write(CHAR_TRILEFT);
				break;
			case 5:
				// clear old pointer on the screen
				lcd.setCursor(0,currentMenu-2);
				lcd.print(F(" "));
				lcd.setCursor(10,currentMenu-2);
				lcd.print(F(" "));
				currentMenu=0;
				// Save the current preset (which number is currentPreset...)
				SavePreset(currentPreset);
				// No need to reload anything because all the global variable are already initialized...
				// Just blink the preset number to show the saving
				lcd.setCursor(17,3);
				lcd.print("\\");
				delay(100);
				lcd.setCursor(17,3);
				lcd.print("||");
				delay(100);
				lcd.setCursor(17,3);
				lcd.print("//");
				delay(100);
				lcd.setCursor(17,3);
				lcd.print("++");
				delay(100);
				affPreset(17,3,currentPreset);
				break;
		}
	}
	switch(currentMenu) {
		case M_PRESETS_CHG:
			menu_presets();
			break;
		case M_RECEIVE_FREQ:
			menu_setFrequencyTuner();
			break;
		case M_TRANSMIT_FREQ:
			menu_setFrequencyTransmitter();
			break;
		case M_COIL:
			menu_setCoil();
			break;
		case M_VOLUME:
			menu_setVolumeTuner();
			break;
	}
}

//------------------------
// change preset
//  - set FM tuning
//  - set AM frequency for transmitter
//  - set CV on antenna coil
//  - set volume
//------------------------
void menu_presets(void) {
bool presetchanged;
	encodeur=readEncodeurs();
	presetchanged=false;
	switch(encodeur) {
		case ENC1UP:
			if (currentPreset <16) {						// if lower than preset number 16
				currentPreset++;							// increment preset by 1
				presetchanged=true;
				affPreset(17,3,currentPreset);				// display presets
				
			}
			break;
		case ENC1DOWN:
			if (currentPreset >1) {							// if upper than preset 1
				currentPreset--;							// decrement preset by 1
				presetchanged=true;
				affPreset(17,3,currentPreset);
			}
			break;
	}
	if (presetchanged) {
		// we need to load the new preset
		// and init all the global variables
		LoadPreset(currentPreset);					// read preset from EEPROM
		// We also need to refresh all the datas on the screen
		refresh_display();
	}
}

//------------------------------------------
// Set SI4703 frequency
// use encoder right-left to set frequency
// press switch to exit
//------------------------------------------
void menu_setFrequencyTuner(void) {
	encodeur=readEncodeurs();
	switch(encodeur) {
		case ENC1UP:
			if (currentChannel <1080) {						// if lower than 108.0 Mhz
				currentChannel++;							// increment channel (100khz...)
				affFreqReceiver(1,0,currentChannel);
				timeFreqChange=millis();
			}
			break;
		case ENC1DOWN:
			if (currentChannel >875) {						// if upper than 88.0 Mhz
				currentChannel--;							// decrement channel (100khz)
				affFreqReceiver(1,0,currentChannel);
				timeFreqChange=millis();
			}
			break;
	}
	changeFrequencyOnDelay();
}

//----------------------------------------------------
// Set AD9833 frequency
// use encoder right-left to set transmitter frequency 150Khz to 1650Khz
// press switch to exit
//----------------------------------------------------
void menu_setFrequencyTransmitter(void) {
	encodeur=readEncodeurs();
	switch(encodeur) {
		case ENC1UP:
			if (currentChannelTransmitter < 1650) {		// if lower than 1650khz
				if (!FreqTransmitInc)					// If slow rate increment
					currentChannelTransmitter+=10;			// then increment
				else
					currentChannelTransmitter++;
				if (currentChannelTransmitter > 1650)
					currentChannelTransmitter=1650;
				affFreqTransmitter(2,1,currentChannelTransmitter);
				timeFreqTransmitterChange=millis();
			}
			break;
		case ENC1DOWN:
			if (currentChannelTransmitter > 150) {		// if upper than 150khz
				if (!FreqTransmitInc)	
					currentChannelTransmitter-=10;			// then decrement
				else
					currentChannelTransmitter--;
				if (currentChannelTransmitter < 150)
					currentChannelTransmitter=150;
				affFreqTransmitter(2,1,currentChannelTransmitter);
				timeFreqTransmitterChange=millis();
			}
			break;
	}
	changeFrequencyTransmitterOnDelay();
}
//----------------------------------------------------
// Set antenna coil variable capacitor
// arbitrary value between 0-100
// *** NOT USED NOW ***
//----------------------------------------------------
void menu_setTuningAntennaCoil(void) {
	encodeur=readEncodeurs();
	switch(encodeur) {
		case ENC1UP:
			if (TuningAntennaCoil <500) {		// if lower than 10pf
				TuningAntennaCoil+=5;			// then increment
				digitsLcdPos(TuningAntennaCoil,3,2,3);
				timeAntennaTuningChange=millis();
			}
			break;
		case ENC1DOWN:
			if (TuningAntennaCoil >10) {		// if upper than 500pf
				TuningAntennaCoil-=5;			// then decrement
				digitsLcdPos(TuningAntennaCoil,3,2,3);
				timeAntennaTuningChange=millis();
			}
			break;
	}
	changeAntennaTuningOnDelay();
}

//----------------------------------------------------
// Set coil selection
// Values : 1, 2, 0 (for the 2 coils in series)
//----------------------------------------------------
void menu_setCoil(void) {
	encodeur=readEncodeurs();
	switch(encodeur) {
		case ENC1UP:
			if (currentAntennaCoil <2) {		// if lower than 10pf
				currentAntennaCoil++;			// then increment
				affCoilSelection(1,2,currentAntennaCoil);
				timeCoilChange=millis();
			}
			break;
		case ENC1DOWN:
			if (currentAntennaCoil >0) {		// if upper than 500pf
				currentAntennaCoil--;			// then decrement
				affCoilSelection(1,2,currentAntennaCoil);
				timeCoilChange=millis();
			}
			break;
	}
	changeCoilOnDelay();
}


//----------------------------------------------------
// Set AD9833 frequency
// use encoder right-left to set transmitter frequency
// press switch to exit
//----------------------------------------------------
void menu_setVolumeTuner(void) {
	encodeur=readEncodeurs();
	switch(encodeur) {
		case ENC1UP:
			if (currentVolumeSI4703 < 15) {		// if lower than 15
				currentVolumeSI4703++;			// then increment
				affVolume(4,3,currentVolumeSI4703);
				setVolume(currentVolumeSI4703);			
			}
			break;
		case ENC1DOWN:
			if (currentVolumeSI4703 >1) {		// if upper than 1
				currentVolumeSI4703--;
				affVolume(4,3,currentVolumeSI4703);
				setVolume(currentVolumeSI4703);			
			}
			break;
	}
}


